#
# spec file for package python-certifi
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-certifi
Version:        2023.11.17
Release:        1.4
Summary:        Python package for providing Mozilla's CA Bundle
License:        MPL-2.0
Group:          Development/Languages/Python
URL:            https://github.com/certifi/python-certifi
Source:         https://files.pythonhosted.org/packages/source/c/certifi/certifi-%{version}.tar.gz
# PATCH-FIX-SUSE -- prefer SUSE certificates
Patch0:         python-certifi-shipped-requests-cabundle.patch
# PATCH-FEATURE-UPSTREAM two-basic-unit-tests.patch gh#certifi/python-certifi#137 mcepl@suse.com
# Add at least primitive test suite (by bnavigator)
Patch1:         two-basic-unit-tests.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  ca-certificates
BuildRequires:  ca-certificates-mozilla
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       ca-certificates
Requires:       ca-certificates-mozilla
BuildArch:      noarch
%python_subpackages

%description
Certifi provides Mozilla's carefully curated collection of Root Certificates
for validating the trustworthiness of SSL certificates while verifying the
identity of TLS hosts. It has been extracted from the Requests project.

Note that on SUSE packages the used CA bundle is actually the system bundle

%prep
%autosetup -p1 -n certifi-%{version}

%build
%python_build

%install
%python_install

%{python_expand chmod +x %{buildroot}%{$python_sitelib}/certifi/core.py
 sed -i "s|#!%{_bindir}/env python|#!%__$python|" %{buildroot}/%{$python_sitelib}/certifi/core.py
 rm %{buildroot}%{$python_sitelib}/certifi/cacert.pem
}

%python_expand $python -m compileall %{buildroot}%{$python_sitelib}/certifi/
%python_expand $python -O -m compileall %{buildroot}%{$python_sitelib}/certifi/

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v certifi.tests.test_certifi

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/certifi/
%{python_sitelib}/certifi-%{version}-py*.egg-info

%changelog
* Tue Nov 28 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.11.17:
  Added certs:
  * Subject: CN=TrustAsia Global Root CA G3 O=TrustAsia Technologies, Inc.
  * Subject: CN=TrustAsia Global Root CA G4 O=TrustAsia Technologies, Inc.
  * Subject: CN=CommScope Public Trust ECC Root-01 O=CommScope
  * Subject: CN=CommScope Public Trust ECC Root-02 O=CommScope
  * Subject: CN=CommScope Public Trust RSA Root-01 O=CommScope
  * Subject: CN=CommScope Public Trust RSA Root-02 O=CommScope
  Removed certs:
  * Subject: CN=Autoridad de Certificacion Firmaprofesional CIF A62634068
* Wed Aug  9 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.7.22:
  Added certs:
  [#] CN=Sectigo Public Server Authentication Root E46 O=Sectigo Limited
  [#] CN=Sectigo Public Server Authentication Root R46 O=Sectigo Limited
  [#] CN=SSL.com TLS RSA Root CA 2022 O=SSL Corporation
  [#] CN=SSL.com TLS ECC Root CA 2022 O=SSL Corporation
  [#] CN=Atos TrustedRoot Root CA ECC TLS 2021 O=Atos
  [#] CN=Atos TrustedRoot Root CA RSA TLS 2021 O=Atos
  Removed certs:
  [#] CN=Hongkong Post Root CA 1 O=Hongkong Post
  [#] CN=E-Tugra Certification Authority O=E-Tu\u011fra EBG Bili\u015fim
    Teknolojileri ve Hizmetleri A.\u015e. OU=E-Tugra Sertifikasyon Merkezi
  [#] CN=E-Tugra Global Root CA RSA v3 O=E-Tugra EBG A.S. OU=E-Tugra Trust Center
  [#] CN=E-Tugra Global Root CA ECC v3 O=E-Tugra EBG A.S. OU=E-Tugra Trust Center
* Mon May  8 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.5.7:
  Added certs:
  * CN=BJCA Global Root CA1 O=BEIJING CERTIFICATE AUTHORITY
* Wed May  3 2023 Dirk Müller <dmueller@suse.com>
- update to 2022.12.7 (bsc#1206212 CVE-2022-23491):
  * obsoletes removeTrustCor.patch in older dists
  Removed certs:
  * CN=Network Solutions Certificate Authority O=Network Solutions L.L.C.
  * CN=Staat der Nederlanden EV Root CA O=Staat der Nederlanden
  * CN=TrustCor RootCert CA-1 O=TrustCor Systems S. de R.L. OU=TrustCor Certificate Authority
  * CN=TrustCor RootCert CA-2 O=TrustCor Systems S. de R.L. OU=TrustCor Certificate Authority
  * CN=TrustCor ECA-1 O=TrustCor Systems S. de R.L. OU=TrustCor Certificate Authority
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Thu Nov 17 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2022.9.24:
  * (no changes)
- from version 2022.09.24:
  * (no changes)
- from version 2022.09.14:
  * (no changes)
- from version 2022.06.15.2:
  * Only use importlib.resources's new files() /
    Traversable API on Python ≥3.11 (#204)
- from version 2022.06.15.1:
  * Fix deprecation warning on Python 3.11 (#199)
  * fixes #198 -- update link in license
- from version 2022.06.15:
  * Add py.typed to MANIFEST.in to package in sdist (#196)
- from version 2022.05.18.1:
  * Add support for Python 3.10 and drop EOL 3.5 (#167)
- from version 2022.05.18:
  * Automatically lock github issues after
    they've been closed for 90 days (#189)
  * Remove universal wheel, python 2 is unsupported (#187)
  * Add type annotations to package
  * Added Required Python Version (#152)
  * Fix homepage link (#145)
- Refresh patches for new version
  * python-certifi-shipped-requests-cabundle.patch
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2021.10.8:
  added certs:
  * CN=TunTrust Root CA O=Agence Nationale de Certification Electronique
  * CN=HARICA TLS ECC Root CA 2021 O=Hellenic Academic and Research Institutions CA
* Thu Jun 17 2021 Dirk Müller <dmueller@suse.com>
- update to 2021.5.30:
  Added certs:
  * CN=AC RAIZ FNMT-RCM SERVIDORES SEGUROS O=FNMT-RCM OU=Ceres
  * CN=GlobalSign Root R46 O=GlobalSign nv-sa
  * CN=GlobalSign Root E46 O=GlobalSign nv-sa
  * CN=GLOBALTRUST 2020 O=e-commerce monitoring GmbH
  * CN=ANF Secure Server Root CA O=ANF Autoridad de Certificacion OU=ANF CA Raiz
  * CN=Certum EC-384 CA O=Asseco Data Systems S.A. OU=Certum Certification Authority
  * CN=Certum Trusted Root CA O=Asseco Data Systems S.A. OU=Certum Certification Authority
* Sat Dec 19 2020 Dirk Müller <dmueller@suse.com>
- update to 2020.12.5
* Thu Nov 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 2020.11.8:
  * Python 3.8+ support
* Wed Nov 25 2020 Matej Cepl <mcepl@suse.com>
- Add two-basic-unit-tests.patch which includes two at least simple test
  patches (gh#certifi/python-certifi#137).
* Sun Aug 16 2020 Benjamin Greiner <code@bnavigator.de>
- Update package description
- Fix the butchered python-certifi-shipped-requests-cabundle.patch
  broken by last update.
- Add comment about missing tests gh#certifi/python-certifi#136
* Sat Aug 15 2020 Arun Persaud <arun@gmx.de>
- specfile:
  * update line numbers and whitespace in patch
- update to version 2020.6.20:
  * Updates in enabled CAs
- changes from version 2020.04.05.2:
  * Document policy for cert addition (#127)
  * Clarify trust origin is Mozilla (#126)
  * Fix where() so that it works with importlib.resources when
    available
  * Goodbye python 2
* Wed Jun  3 2020 Dirk Mueller <dmueller@suse.com>
- update to 2020.4.5.1:
  adds Agencia Catalana de Certificacio (NIF Q-0801176-I) OU=Serveis
  Publics de Certificacio/Vegeu
* Fri Jan 24 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 2019.11.28
  * Updates in enabled CAs
* Fri Sep 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Sync to the latest 2019.9.11:
  * Updates in enabled CAs
* Wed Jul 24 2019 pgajdos@suse.com
- version update to 2019.6.16
  * remove Certinomis Root CA
* Mon Mar 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2019.3.9:
  * Add emSign Root CA - G1
  * Add emSign ECC Root CA - G3
  * Add Hongkong Post Root CA 3
- Rebase python-certifi-shipped-requests-cabundle.patch
* Mon Feb 11 2019 John Vandenberg <jayvdb@gmail.com>
- Update to 2018.11.29
  * Deprecated old_where() has been removed
  * Removed certificates
    + Visa eCommerce Root
    + Certplus Root CA G1
    + Certplus Root CA G2
    + OpenTrust Root CA G1
    + OpenTrust Root CA G2
    + OpenTrust Root CA G3
* Tue Jan  8 2019 Jonathan Brownell <jbrownell@suse.com>
- Limit SUSE certificate patch to exclude Red Hat platforms since
  the relevant /etc/ssl/ca-bundle.pem does not exist there
- %%py_compile and %%py3_compile macros do not exist on Red Hat;
  substitute them with equivalent %%python_exec invocations
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Apr 17 2018 michael@stroeder.com
- update to 2018.4.16
  * Remove Elektronik Sertifika Hizket from cacert.pem
- This is noop as we use our cacert list from /etc/ssl/ca-bundle.pem
* Sun Feb  4 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2018.1.18:
  * Remove 1024-bit root certificates
  * Include license in the list of trove classifiers
  * Include license file in the generated wheel package
* Tue Nov 14 2017 dmueller@suse.com
- update to 2017.11.5:
  * Sync with bundle mozilla release
- remove  python-certifi-fix-version-string.patch: obsolete
* Wed Oct 18 2017 jmatejek@suse.com
- fix macros to support not having python2
* Thu Oct 12 2017 adrian.glaubitz@suse.com
- add patch to fix version string from 2017.07.27.1 to
  2017.7.27.1 to fix the build on SLE12_SP3 and earlier
  + python-certifi-fix-version-string.patch
* Tue Oct  3 2017 arun@gmx.de
- updated patch
- update to version 2017.7.27.1:
  * Use a more expressive API for getting the dir a path is in
  * set zip_safe=False to help out setuptools (#63)
  * Change license from ISC to MPL-2.0 in setup.py
  * Add trove classifiers for missing supported Python versions
  * Rename [wheel] section to [bdist_wheel] as the former is legacy
* Mon Jul 10 2017 toddrme2178@gmail.com
- Fix wrong-script-interpreter rpmlint error.
- Fix script-without-shebang rpmlint warning.
* Sun Jun 11 2017 dmueller@suse.com
- require ca-certificates-mozilla, otherwise certifi does not
  provide any ca bundle (the bundled one that openSUSE patches
  out is the mozilla bundle as well)
* Sat Jun 10 2017 dmueller@suse.com
- update to 2017.4.17
* Sat Apr  8 2017 aloisio@gmx.com
- Updated to version 2017.1.23
- Converted to single-spec
- Updated source URL
* Fri Jun  3 2016 jacobwinski@gmail.com
- Update to version 2016.2.28
- Update copyright year in spec file
- Fix executable warning (fix taken from python3-certifi)
* Fri Jan 22 2016 michael@stroeder.com
- Update to version 2015.11.20.1
* Sat Sep 26 2015 toddrme2178@gmail.com
- Update to version 2015.9.6.2:
  * Actually ship weak cert bundle.
  * Provide old cert bundle.
  * Use secure roots by default.
  * Update scripts to use mkcert.org
  * Concatenate the two roots
  * Add the needed 1024-bit roots
  * Move mkcert output to non-core file
- Fix dependencies on SLES 11
- Certifi is released under MPL-2.0; fix the license tag
- Rebase python-certifi-shipped-requests-cabundle.patch
* Wed Apr 22 2015 mcihar@suse.cz
- Initial packaging
